# Amplo - Automated Machine Learning
[![image](https://img.shields.io/pypi/v/amplo.svg)](https://pypi.python.org/pypi/amplo)
[![image](https://github.com/nielsuit227/AutoML/workflows/docs/badge.svg)](https://github.com/nielsuit227/AutoML/workflows/docs/badge.svg)
[![image](https://github.com/nielsuit227/AutoML/workflows/build/badge.svg)](https://github.com/nielsuit227/AutoML/workflows/build/badge.svg)


This repo is the beginning of something beautiful. The automated machine learning pipeline will become public soon, and will have proper testing and CI/CD integrated.
